package girdpanetest;

import java.io.File;
import java.net.URL;
import java.util.Random;
import java.util.ResourceBundle;
import javafx.event.ActionEvent;
import javafx.fxml.FXML;
import javafx.fxml.Initializable;
import javafx.scene.Node;
import javafx.scene.control.Label;
import javafx.scene.layout.BorderPane;
import javafx.scene.layout.GridPane;
import javafx.stage.FileChooser;

public class FXMLDocumentController implements Initializable {

    @FXML
    private Label label;

    @FXML
    private BorderPane borderPane;

    @FXML
    private GridPane gridPane;

    @FXML
    private void handleButtonAction(ActionEvent event) {
        System.out.println("You clicked me!");
        label.setText("Hello World!");
        
        // just an example on how to color the existing panel in each cell
        Random random = new Random();
        for (int row = 0; row < 20; row++) {
            for (int col = 0; col < 10; col++) {
                Node cell = getCellFromGridPane(gridPane, row, col);
                StringBuilder color = new StringBuilder();
                for (int digit = 0; digit < 6; digit++) {
                    color.append(String.valueOf(random.nextInt(10)));
                }
                // here you set the property "background color" to a given color
                cell.setStyle("-fx-background-color: #" + color.toString());
            }
        }
    }

    @Override
    public void initialize(URL url, ResourceBundle rb) {
        // this method is called everytime a GUI is created. This is where you
        // put commands that you want to do as an initialization process.
        // instead of creating manually a grid panel with 10 rows by 20 columns
        // in the SceneBuilder. I decided to create it here via 2 nested FOR
        // loops. I am also creating labels to be placed in the grid pane cells
        // the existing gridPane in the SceneBuilder is rewritten here, so it 
        // does not matter how many rows and columns you put in the scenebuilder
        // this is to make easier to create such a big grid pane.
        gridPane = new GridPane();
        for (int x = 0; x < 20; x++) {
            for (int y = 0; y < 10; y++) {
                // creating the labels
                Label label = new Label("  ");
                
                // binding the label size with the gridpane size, so that
                // when we resize the window the cells will be changed and the
                // labels also. Try to resize your application to see this happening
                label.prefWidthProperty().bind(gridPane.widthProperty());
                label.prefHeightProperty().bind(gridPane.heightProperty());
                
                // add label to the gridPane, but getting the gridPAne "children"
                // (cells) and adding one more child (cell) to the gridPane
                gridPane.getChildren().add(label);
                
                // this is needed to use the getCellFromGridPane() method below
                GridPane.setColumnIndex(label, x);
                GridPane.setRowIndex(label, y);
            }
        }
        gridPane.setGridLinesVisible(true);
        borderPane.setCenter(gridPane);
    }

    private Node getCellFromGridPane(GridPane gridPane, int col, int row) {
        // this method returns a cell ID for a given row and column in the gridpane
        for (Node node : gridPane.getChildren()) {
            if (GridPane.getColumnIndex(node) == col && GridPane.getRowIndex(node) == row) {
                return node;
            }
        }
        return null;
    }
    
    @FXML
    void onBrowseButtonClicked(ActionEvent event) {
        // an example of how to use the FileChooser.
        // After getting "file" use what you have learned in class to open the
        // text file and read its data.
        FileChooser fileChooser = new FileChooser();
        fileChooser.setTitle("Opening Land Map File");
        File file = fileChooser.showOpenDialog(null);
    }
}
